%{!?kernel_version: %{expand: %%define kernel_version %(uname -r|sed -e 's/EL.*$/EL/g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | sed -e 's/.*EL//g' | sed -e 's/^$/up/g')}}

# On RHEL 4, up type has no tag
%if "%{type}" != "up"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%define kernel_devel kernel-%{type}-devel
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%define kernel_devel kernel-devel
%endif

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vmhgfs'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-db.pl --os=linux,rhel,4
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vmhgfs/vmware-pmwv.pl --os=linux,rhel,4 --release=%{kernel_dir} --build 3227872 --modKey %{modKey}
%define kmp_version %version

Name:         vmware-tools-vmhgfs
BuildRequires: %{kernel_devel} gcc
Requires:     vmware-tools-vmhgfs-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vmhgfs-kmp
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      The vmhgfs kernel module built for the %{kernel_version} kernel.
Epoch:        0
Version:      2.0.17.1
Release:      %{kversionreltag}.5.el4
BuildRoot:    %{_tmppath}/%{name}-%{version}-build


Source0:      vmhgfs.tar

%prep
%setup -n vmhgfs-only

%build
make clean
make

# NOTE: RHEL 4 has MODVERSIONS enabled but does not generate the module.symvers
#       file we would need in order to properly propagate symbol versions
#       in-between interdependent kernel modules.  See bug 568405 for more info.
if [ "vmhgfs" = "vsock" ]; then
   echo
   echo
   echo "Please ignore the \"VMCI_ ... undefined!\" warnings generated by the build system."
   echo "The vmhgfs module will load and function properly despite those warnings."
   echo
   echo
fi

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
# The following command copies our newly build kernel module to a known
# location.  Unfortunately sometimes the kmod source build places the kmods
# in inconsistent locations.
cp ../vmhgfs.o . 2>/dev/null || true
cp driver-%{kernel_version}/vmhgfs-xxx-%{kernel_version} ./vmhgfs.o 2>/dev/null || true

# Install kernel module
install -m 644 -D vmhgfs.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/%{name}/vmhgfs.ko

%package kmp-%{type}
Summary:      The vmhgfs kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vmhgfs-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vmhgfs-kmp
Release:      %{kversionreltag}.5.el4



%description
 This package enables you to build binary kernel module packages (kmps) for vmhgfs.  The vmhgfs driver is the host-guest file system client which provides a file system interface using a specific namespace for guest user applications to perform file operations, to access or create new files which reside on the host. The vmhgfs driver communicates with the host-guest file system server which runs on the host.

%description kmp-%{type}
 This package contains a pre-compiled vmhgfs module for use with the %{kernel_version} kernel.   The vmhgfs driver is the host-guest file system client which provides a file system interface using a specific namespace for guest user applications to perform file operations, to access or create new files which reside on the host. The vmhgfs driver communicates with the host-guest file system server which runs on the host.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmhgfs stop || true
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%post kmp-%{type}
# Configure
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/%{name}/vmhgfs.ko

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*EL//g'`
if [ -z "$kmodType" ]; then
   kmodType=up
fi
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vmhgfs start || true
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vmhgfs stop || true
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/%{name}/vmhgfs.ko


